@@ -1,16 +1,26 @@
-/* --< GKrellShoot 0.3.2 >--{ 17 August 2002 }--
+/* --< GKrellShoot 0.4.1 >--{ 17 August 2002 }--
+ * Ported to Gkrellm2.0
  *
  * Author: M.R.Muthu Kumar (m_muthukumar@users.sourceforge.net)
  *
  * All the graphic routines are from - Tom Gilbert ( http://linuxbrit.co.uk/ )
  */
 
-#include <gkrellm/gkrellm.h>
+#include <gkrellm2/gkrellm.h>
+
+/*
+ * Make sure we have a compatible version of GKrellM
+ * (Version 2.0+ is required 
+ */
+#if !defined(GKRELLM_VERSION_MAJOR) \
+     || (GKRELLM_VERSION_MAJOR < 2 ) 
+#error This plugin requires GKrellM version >= 2.0
+#endif
 
 #include<math.h>
 
-#define GKRELLSHOOT_VER 	"0.3.2"
-#define DEFAULT_XLOCK		"xscreensaver-command -lock &"
+#define GKRELLSHOOT_VER 	"0.4.1"
+#define DEFAULT_XLOCK		"xscreensaver-command -lock"
 #define SHOOT_SCREEN		"import -window root"
 #define SHOOT_WINDOW		"import"
 #define DEFAULT_VIEW		"ee"
@@ -50,16 +60,16 @@ static gchar *anim_name[] = { B_BALL, MESH, RADAR, SINE, STAR, RAIN, R_LINE,
 static gint  current_anim[MAX_PANELS];
 static gint  cycle_anim[MAX_PANELS];
 
-static Monitor		*mon;
-static Chart		*chart[MAX_PANELS];
-static ChartConfig	*chart_config=NULL;
+static GkrellmMonitor		*mon;
+static GkrellmChart		*chart[MAX_PANELS];
+static GkrellmChartconfig	*chart_config=NULL;
 
-static Panel	*panel;
+static GkrellmPanel	*panel;
 
-static Decal	*decal_lock,
+static GkrellmDecal	*decal_lock,
 		*decal_shoot;
 
-static gint     chart_w = 60;
+static gint		chart_w = 60;
 static gint		style_id;
 
 static gint wait_seconds;
@@ -73,7 +83,7 @@ static gchar shoot_cmd[1024];
 
 static gint active_panels=1;
 static gint sel_num_panels=1;
-static gint panel_visible[MAX_PANELS];
+static gboolean panel_visible[MAX_PANELS];
 
 
 
@@ -135,7 +145,10 @@ gchar filename[512];
 int load_val = 50;
 struct tm  *tm;
 
-guchar *rgbbuf[MAX_PANELS];
+GkrellmTicks *gk_ticks;
+
+
+guchar *rgbbuf_t[MAX_PANELS];
 
 static void change_num_panels ();
 
@@ -146,11 +159,11 @@ set_col_pixel (gint x, gint y,  guchar c,  guchar rrr,
 {
   guchar *ptr;
 
-  if ((((int) c) == 0) || (x < 0) || (y < 0) || (x > chart_w -1) || (y > 39))
+  if ((((int) c) == 0) || (x < 0) || (y < 0) || (x > chart_w - 1) || (y > 39))
     return;
  
 
-  ptr = rgbbuf[chart_index] + ( chart_w * 3 * (y)) + (3 * x);
+  ptr = rgbbuf_t[chart_index] + ( chart_w * 3 * (y)) + (3 * x);
   ptr[0] = ((double) rrr / 255 * (double) c);
   ptr[1] = ((double) ggg / 255 * (double) c);
   ptr[2] = ((double) bbb / 255 * (double) c);
@@ -160,7 +173,7 @@ static void color_buf( gint chart_index, guchar rrr, guchar ggg, guchar bbb  )
   guchar *pos;
   gint y, x;
 
-  pos = rgbbuf[chart_index];
+  pos = rgbbuf_t[chart_index];
   for (y = 0; y < CHART_H; y++)
     {
       for (x = 0; x < chart_w; x++)
@@ -180,7 +193,7 @@ static void fade_buf( gint per, gint chart_index )
   guchar *pos;
   gint y, x;
 
-  pos = rgbbuf[chart_index];
+  pos = rgbbuf_t[chart_index];
   for (y = 0; y < CHART_H; y++)
     {
       for (x = 0; x < chart_w; x++)
@@ -201,7 +214,7 @@ blank_buf( gint chart_index )
   guchar *pos;
   gint x,y;
 
-  pos = rgbbuf[chart_index];
+  pos = rgbbuf_t[chart_index];
   for (y = 0; y < CHART_H; y++)
     {
       for (x = 0; x < chart_w; x++)
@@ -221,7 +234,7 @@ scroll_buf ( gint chart_index )
 
   for (y = 0; y < 40; y++)
     {
-      rgb = rgbbuf[chart_index];
+      rgb = rgbbuf_t[chart_index];
       rptr = rgb + (y * chart_w * 3);
       for (x = 0; x < chart_w - 1; x++)
         {
@@ -272,7 +285,6 @@ draw_ball ( gint chart_index )
   ball_x[chart_index] += d_x[chart_index];
   ball_y[chart_index] += d_y[chart_index];
 
-
   if (ball_x[chart_index] < 1)
     {
       ball_x[chart_index] = 1;
@@ -361,7 +373,7 @@ static void draw_radar( gint chart_index )
     {
       radar_x[chart_index][i] += 0.07;
 
-      tempX = ( tmp_w - 1 ) + radar_r[chart_index][i] * cos (radar_x[chart_index][i]) / 3;
+      tempX = (tmp_w - 1) + radar_r[chart_index][i] * cos (radar_x[chart_index][i]) / 3;
       tempY = 19 + radar_r[chart_index][i] * sin (radar_x[chart_index][i]) / 3;
 
       set_col_pixel (tempX, tempY, 255, 55, 255, 75, chart_index);
@@ -655,7 +667,7 @@ static gdouble z[49];
 static void
 draw_rotator ( gint chart_index )
 {
-  gint xx = (chart_w / 2) - 1;
+  gint xx = (chart_w / 2 ) - 1;
   gint yy = 19;
 
   /* following static array variables must be initialized upto MAX_PANELS */
@@ -904,7 +916,7 @@ draw_rstar ( gint chart_index )
 
   x[chart_index] += 0.04;
 
-  tmp_w = (chart_w / 2) - 1;
+  tmp_w = (chart_w / 2 ) - 1;
   x1 = tmp_w + radius * cos (x[chart_index]) ;
   y1 = 19 + radius * sin (x[chart_index]) ;
   x2 = tmp_w + radius * cos (x[chart_index] + (2 * M_PI / 3)) ;
@@ -1036,7 +1048,7 @@ draw_scanner (gint chart_index)
       setup[chart_index] = 1;
   }
 
-  if (GK.minute_tick && ++minute_timer[chart_index] >= 2 )
+  if (gk_ticks->minute_tick && ++minute_timer[chart_index] >= 2 )
   {
     minute_timer[chart_index] = 0;
 
@@ -1208,7 +1220,7 @@ chart_expose_event(GtkWidget *widget, GdkEventExpose *ev, gpointer echart )
 
    gdk_draw_rgb_image (widget->window, widget->style->fg_gc[GTK_STATE_NORMAL],
                       0, 0, chart_w, CHART_H,
-                      GDK_RGB_DITHER_MAX, rgbbuf[i], chart_w * 3);
+                      GDK_RGB_DITHER_MAX, rgbbuf_t[i], chart_w * 3);
    return TRUE;
 }
 
@@ -1288,7 +1300,7 @@ run_xlock_cmd()
 {
   if ( xlock_cmd )
   {
-     system( xlock_cmd );
+     g_spawn_command_line_async( xlock_cmd, NULL );
   }
   return;
 }
@@ -1298,7 +1310,7 @@ update_cycle_anim( gint i )
 {
   static gint minute_timer[] = { 0,0,0 }; // shoud have MAX_PANELS array size.
 
-  if (GK.minute_tick && ++minute_timer[i] >= cycle_anim[i] )
+  if (gk_ticks->minute_tick && ++minute_timer[i] >= cycle_anim[i] )
   {
     switch_anim(i, FALSE);
     minute_timer[i] = 0;
@@ -1332,7 +1344,11 @@ make_shoot_cmd(void)
    gchar tmp_scmd[32];
    gchar tmp_fcmd[32];
 
-   sprintf( tmp_scmd, "sleep %d &&", wait_seconds );
+   if ( wait_seconds > 0 )
+   {
+     sprintf( tmp_scmd, "sleep %d &&", wait_seconds );
+   }
+   else { sprintf( tmp_scmd, "%s", " " ); }
 
    if ( with_frame ) { sprintf( tmp_fcmd, " %s ", "-frame" ); }
    else { sprintf( tmp_fcmd, "%s", " " ); }
@@ -1380,13 +1396,13 @@ run_shoot_cmd()
 
   if ( shoot_cmd )
   {
-     system( shoot_cmd );
+     system ( shoot_cmd );
   }
   return;
 }
 
 static void
-cb_button(DecalButton *button)
+cb_button(GkrellmDecalbutton *button)
 {
   if (GPOINTER_TO_INT(button->data) == 0)
   {
@@ -1402,8 +1418,8 @@ cb_button(DecalButton *button)
 static void
 create_plugin(GtkWidget *vbox, gint first_create)
 {
-	Style			*style;
-	TextStyle		*ts, *ts_alt;
+	GkrellmStyle			*style;
+	GkrellmTextstyle		*ts, *ts_alt;
 
 	gint			x,y, i;
 	gint			tmp_w;
@@ -1424,8 +1440,8 @@ create_plugin(GtkWidget *vbox, gint first_create)
 	  gkrellm_destroy_decal_list(panel); 
 	}
 
-	  for ( i=0; i < MAX_PANELS; i++ )
-    {	
+	for ( i=0; i < MAX_PANELS; i++ )
+        {	
 	  gkrellm_set_chart_height_default(chart[i], 40);
 	  gkrellm_chart_create(vbox, mon, chart[i], &chart_config);
 	}
@@ -1456,9 +1472,8 @@ create_plugin(GtkWidget *vbox, gint first_create)
 	/* Configure the panel to hold the above created decals, add in a little
 	|  bottom margin for looks, and create the panel.
 	*/
-        gkrellm_configure_panel(panel, NULL, style);
-        gkrellm_create_panel(vbox, panel, gkrellm_bg_meter_image(style_id));
-        gkrellm_monitor_height_adjust(panel->h);
+        gkrellm_panel_configure(panel, NULL, style);
+        gkrellm_panel_create(vbox, mon, panel );
 
         /* After the panel is created, the decals can be converted into buttons.
         |  First draw the initial text into the text decal button and then
@@ -1466,11 +1481,11 @@ create_plugin(GtkWidget *vbox, gint first_create)
         */
         gkrellm_draw_decal_text(panel, decal_lock, "Lock", 0 ); 
         gkrellm_put_decal_in_meter_button(panel, decal_lock, cb_button,
-                                GINT_TO_POINTER(0));
+                                GINT_TO_POINTER(0), NULL);
 
         gkrellm_draw_decal_text(panel, decal_shoot, "Shoot", 0 ); 
         gkrellm_put_decal_in_meter_button(panel, decal_shoot, cb_button,
-                                GINT_TO_POINTER(1));
+                                GINT_TO_POINTER(1), NULL);
 
 	/* Note: all of the above gkrellm_draw_decal_XXX() calls will not
 	|  appear on the panel until a 	gkrellm_draw_layers(panel); call is
@@ -1478,7 +1493,7 @@ create_plugin(GtkWidget *vbox, gint first_create)
 	|  update_plugin().
 	*/
 
-        gkrellm_draw_layers(panel);
+        gkrellm_draw_panel_layers(panel);
 
         if (shoot_tips == NULL)
         {
@@ -1489,15 +1504,15 @@ create_plugin(GtkWidget *vbox, gint first_create)
           gtk_tooltips_set_delay(shoot_tips, 1000);
         }
 
-	tmp_w = gkrellm_chart_width();
+    tmp_w = gkrellm_chart_width();
     if ( chart_w != tmp_w )
-    {
+    {   
        chart_w = tmp_w;
        for ( i = 0; i < MAX_PANELS; i++ )
-	   {
-         rgbbuf[i] = g_renew( guchar, rgbbuf[i], chart_w * CHART_H * 3 );
-         blank_buf(i);
-	   }	 
+           {
+             rgbbuf_t[i] = g_renew( guchar, rgbbuf_t[i],chart_w * CHART_H * 3 );
+             blank_buf(i);
+           }     
     }
 
 	if (first_create)
@@ -1520,11 +1535,12 @@ create_plugin(GtkWidget *vbox, gint first_create)
 
 	    gdk_rgb_init();
 
-        for ( i = 0; i < MAX_PANELS; i++ )
-		{
+            for ( i = 0; i < MAX_PANELS; i++ )
+	    {
 	      blank_buf( i );
-          gkrellm_chart_enable_visibility (chart[i],i < active_panels, &panel_visible[i]);
-	    }
+              gkrellm_chart_enable_visibility(chart[i], i < active_panels , 
+                                      &panel_visible[i] );
+            }
 	}  
 
 }
@@ -1633,6 +1649,7 @@ static void
 apply_shoot_config (void)
 {
     gchar *c;
+    const gchar *c_text;
 
 	gint i;
 
@@ -1648,7 +1665,7 @@ apply_shoot_config (void)
 
    for ( i=0; i < active_panels; i++ )
    {
-     c = gkrellm_entry_get_text(&(GTK_COMBO(anim_select_option[i])->entry));
+     c = gkrellm_gtk_entry_get_text(&(GTK_COMBO(anim_select_option[i])->entry));
      if (strcmp(anim_select[i], c) && valid_anim_type( c, i ) ) {
 	  strcpy( anim_select[i], c );
 
@@ -1658,19 +1675,19 @@ apply_shoot_config (void)
             GTK_SPIN_BUTTON(cycle_anim_option[i]));
    }
 
-    c = gtk_entry_get_text(GTK_ENTRY(xlock_cmd_option));
-    if (strcmp(xlock_cmd, c)) {
-	  strcpy( xlock_cmd, c );
+    c_text = gtk_entry_get_text(GTK_ENTRY(xlock_cmd_option));
+    if (strcmp(xlock_cmd, c_text)) {
+	  strcpy( xlock_cmd, c_text );
     }
 
-    c = gtk_entry_get_text(GTK_ENTRY(view_cmd_option));
-    if (strcmp(view_cmd, c)) {
-	strcpy( view_cmd, c );    
+    c_text = gtk_entry_get_text(GTK_ENTRY(view_cmd_option));
+    if (strcmp(view_cmd, c_text)) {
+	strcpy( view_cmd, c_text );    
     }
 
-    c = gtk_entry_get_text(GTK_ENTRY(image_format_option));
-    if (strcmp(image_format, c)) {
-	strcpy( image_format, c );    
+    c_text = gtk_entry_get_text(GTK_ENTRY(image_format_option));
+    if (strcmp(image_format, c_text)) {
+	strcpy( image_format, c_text );    
     }
 
     wait_seconds = gtk_spin_button_get_value_as_int(
@@ -1769,7 +1786,8 @@ static void change_num_panels()
   for ( i = 0; i < MAX_PANELS; i++ )
   {
      blank_buf( i );
-     gkrellm_chart_enable_visibility (chart[i],i < sel_num_panels , &panel_visible[i] );
+     gkrellm_chart_enable_visibility(chart[i], i < sel_num_panels , 
+                                      &panel_visible[i] );
   }							 
 
   for ( i = active_panels; i < sel_num_panels; i++ )
@@ -1962,10 +1980,10 @@ create_shoot_tab (GtkWidget *tab)
     GTK_POLICY_AUTOMATIC, GTK_POLICY_AUTOMATIC);
     gtk_container_add(GTK_CONTAINER(frame), info_window);
 
-    text = gtk_text_new(NULL, NULL);
+    text = gtk_text_view_new();
 
-    gkrellm_add_info_text(text, help_text, sizeof(help_text)/sizeof(gchar*));
-    gtk_text_set_editable(GTK_TEXT(text), FALSE);
+    gkrellm_gtk_text_view_append_strings(text, help_text, sizeof(help_text)/sizeof(gchar*));
+    gtk_text_view_set_editable(GTK_TEXT_VIEW(text), FALSE);
     gtk_container_add(GTK_CONTAINER(info_window), text);
 
     label = gtk_label_new("Help");
@@ -1992,7 +2010,7 @@ create_shoot_tab (GtkWidget *tab)
 
 /* The monitor structure tells GKrellM how to call the plugin routines.
 */
-static Monitor	plugin_mon	=
+static GkrellmMonitor	plugin_mon	=
 	{
 	CONFIG_NAME,        	/* Name, for config tab.    */
 	0,			/* Id,  0 if a plugin       */
@@ -2031,7 +2049,8 @@ read_default(void)
      current_anim[i] = i + 1;
 	 if ( i >= MAX_ANIM) { current_anim[i] = 0; }
      sprintf( anim_select[i],"%s",  anim_name[current_anim[i]] );
-     rgbbuf[i] = g_new0( guchar, chart_w * CHART_H * 3 );
+	 rgbbuf_t[i] = g_new0( guchar, chart_w * CHART_H * 3 );
+
    }
 
    sprintf( xlock_cmd,"%s",  DEFAULT_XLOCK );
@@ -2039,14 +2058,16 @@ read_default(void)
    sprintf( image_format,"%s",  DEFAULT_IMAGE );
 
    strcpy( filename, DEFAULT_OUTFILE );
+
+   gk_ticks = gkrellm_ticks();
 }	
 
 
   /* All GKrellM plugins must have one global routine named init_plugin()
   |  which returns a pointer to a filled in monitor structure.
   */
-Monitor *
-init_plugin()
+GkrellmMonitor *
+gkrellm_init_plugin()
 	{
 	/* If this call is made, the background and krell images for this plugin
 	|  can be custom themed by putting bg_meter.png or krell.png in the
@@ -2060,6 +2081,7 @@ init_plugin()
 
 	/* style_id = gkrellm_lookup_meter_style_id(CAL_STYLE_NAME); */
 
+
 	read_default();
 
 	mon = &plugin_mon;
